@@ -33,6 +33,8 @@ struct _GgvControlPrivate {
 
 	GtkWidget *root;
 
+	GtkObject *zoom_adj;
+
 	BonoboUIComponent *uic, *popup_uic;
 };
 
@@ -139,6 +141,11 @@ zoomable_set_zoom_level_cb (BonoboZoomable *zoomable, float new_zoom_level,
 	control->priv->zoom_level = ggv_postscript_view_get_zoom_factor
 		(control->priv->ps_view);
 
+	if(control->priv->zoom_adj) {
+		gtk_adjustment_set_value(GTK_ADJUSTMENT(control->priv->zoom_adj),
+								 new_zoom_level*100.0);
+	}
+
 	bonobo_zoomable_report_zoom_level_changed
 		(zoomable, control->priv->zoom_level, NULL);
 
@@ -386,7 +393,7 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 							  "zoom_out");
 		break;
 	default:
-                return FALSE;
+		return FALSE;
 	}
 
 	return TRUE;
@@ -505,6 +512,17 @@ static BonoboUIVerb ggv_control_verbs[] = {
 
 extern BonoboUIVerb ggv_postscript_view_verbs[];
 
+static void 
+zoom_adj_value_changed_cb(GtkAdjustment *adj, gpointer data)
+{
+	GgvControl *control = GGV_CONTROL(data);
+
+	if(fabs(adj->value - ggv_postscript_view_get_zoom_factor(control->priv->ps_view)) > 0.001) {
+		g_signal_emit_by_name(G_OBJECT (control->priv->zoomable),
+							  "set_zoom_level", ((gfloat)adj->value)/100.0);
+	}
+}
+
 static void
 ggv_control_create_ui (GgvControl *control)
 {
@@ -543,6 +561,35 @@ ggv_control_create_ui (GgvControl *control)
 												control->priv->ps_view);
 	ggv_postscript_view_set_popup_ui_component(control->priv->ps_view,
 											   control->priv->popup_uic);
+
+	if(!control->priv->has_zoomable_frame || TRUE /* lets set this to nautilus as well */) {
+		BonoboControl *zoom_control;
+		GtkWidget *zoom_spin, *zoom_image, *perc_label, *hbox;
+		GtkObject *zoom_adj;
+
+		hbox = gtk_hbox_new(FALSE, 2);
+		gtk_widget_show(hbox);
+		zoom_image = gtk_image_new_from_file(GNOMEICONDIR "/ggv/zoom.xpm");
+		gtk_widget_show(zoom_image);
+		gtk_box_pack_start(GTK_BOX(hbox), zoom_image, FALSE, TRUE, 0);
+		zoom_adj = gtk_adjustment_new(ggv_postscript_view_get_zoom_factor(control->priv->ps_view)*100.0,
+									  16.67, 600.0, 10.0, 100.0, 100.0);
+		g_signal_connect(G_OBJECT(zoom_adj), "value-changed",
+						 G_CALLBACK(zoom_adj_value_changed_cb), control);
+		zoom_spin = gtk_spin_button_new(GTK_ADJUSTMENT(zoom_adj), 1.0, 0);
+		gtk_widget_show(zoom_spin);
+		gtk_box_pack_start(GTK_BOX(hbox), zoom_spin, TRUE, TRUE, 0);
+		perc_label = gtk_label_new("%");
+		gtk_widget_show(perc_label);
+		gtk_box_pack_start(GTK_BOX(hbox), perc_label, FALSE, TRUE, 0);
+		zoom_control = bonobo_control_new(hbox);
+		bonobo_ui_component_object_set(control->priv->uic, "/Sidebar/Zoom Control Placeholder/ZoomControl",
+									   BONOBO_OBJREF(zoom_control), NULL);
+#if 0
+		bonobo_object_unref(BONOBO_OBJECT(zoom_control));
+#endif
+		control->priv->zoom_adj = zoom_adj;
+	}
 }
 
 static void
@@ -604,7 +651,6 @@ ggv_control_activate (BonoboControl *object, gboolean state)
 static void
 ggv_control_class_init (GgvControlClass *klass)
 {
-	BonoboUINode *placeholder, *item;
 	GObjectClass *object_class = (GObjectClass *)klass;
 	BonoboObjectClass *bonobo_object_class = (BonoboObjectClass *)klass;
 	BonoboControlClass *control_class = (BonoboControlClass *)klass;
@@ -676,6 +722,8 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 	gtk_widget_show(control->priv->root);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(control->priv->root),
 										GTK_SHADOW_IN);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(control->priv->root),
+								   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	g_signal_connect(G_OBJECT(GTK_SCROLLED_WINDOW(control->priv->root)->hscrollbar),
 					 "button_press_event",
 					 G_CALLBACK(scrollbar_button_press_event),
