@@ -87,6 +87,7 @@ ggv_prefs_dialog_apply(GgvPrefsDialog *dlg)
         ggv_menubar = GTK_TOGGLE_BUTTON(dlg->mbar)->active;
         ggv_statusbar = GTK_TOGGLE_BUTTON(dlg->sbar)->active;
         ggv_autojump = GTK_TOGGLE_BUTTON(dlg->auto_jump)->active;
+        ggv_right_panel = GTK_TOGGLE_BUTTON(dlg->right_panel)->active;
 
         gtk_gs_defaults_save();
 
@@ -226,6 +227,8 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
                                      ggv_save_geometry);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->auto_jump),
                                      ggv_autojump);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->right_panel),
+                                     ggv_right_panel);
 
         gtk_entry_set_text(GTK_ENTRY(dlg->gs),
                            gtk_gs_defaults_get_interpreter_cmd());
@@ -521,7 +524,7 @@ ggv_prefs_dialog_new()
         gtk_notebook_append_page(GTK_NOTEBOOK(dlg->notebook), table, label);
 
         /* Layout page */
-        table = gtk_table_new(7, 1, FALSE);
+        table = gtk_table_new(8, 1, FALSE);
 
         /* show side panel */
         dlg->sidebar = gtk_check_button_new_with_label(_("Show side panel by default"));
@@ -534,10 +537,20 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->sidebar);
 
+        dlg->right_panel = gtk_check_button_new_with_label(_("Put side panel in Nautilus on the right"));
+        gtk_table_attach(GTK_TABLE(table), dlg->right_panel,
+                         0, 1, 1, 2,
+                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        g_signal_connect(G_OBJECT(dlg->right_panel), "clicked",
+                         G_CALLBACK(prefs_dlg_change_handler), dlg);
+        gtk_widget_show(dlg->right_panel);
+
         /* show menubar */
         dlg->mbar = gtk_check_button_new_with_label(_("Show menubar by default"));
         gtk_table_attach(GTK_TABLE(table), dlg->mbar,
-                         0, 1, 1, 2,
+                         0, 1, 2, 3,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -547,7 +560,7 @@ ggv_prefs_dialog_new()
 	/* show toolbar */
         dlg->toolbar = gtk_check_button_new_with_label(_("Show toolbar by default"));
         gtk_table_attach(GTK_TABLE(table), dlg->toolbar,
-                         0, 1, 2, 3,
+                         0, 1, 3, 4,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -558,7 +571,7 @@ ggv_prefs_dialog_new()
         /* show toolbar labels */
         dlg->tblabels = gtk_check_button_new_with_label(_("Show labels in toolbar"));
         gtk_table_attach(GTK_TABLE(table), dlg->tblabels,
-                         0, 1, 3, 4,
+                         0, 1, 4, 5,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -569,7 +582,7 @@ ggv_prefs_dialog_new()
         /* show statusbar */
         dlg->sbar = gtk_check_button_new_with_label(_("Show statusbar by default"));
         gtk_table_attach(GTK_TABLE(table), dlg->sbar,
-                         0, 1, 4, 5,
+                         0, 1, 5, 6,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -580,7 +593,7 @@ ggv_prefs_dialog_new()
         /* save geometry */
         dlg->savegeo = gtk_check_button_new_with_label(_("Save geometry"));
         gtk_table_attach(GTK_TABLE(table), dlg->savegeo,
-                         0, 1, 5, 6,
+                         0, 1, 6, 7,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -590,7 +603,7 @@ ggv_prefs_dialog_new()
         /* auto jump to beginning of page */
         dlg->auto_jump= gtk_check_button_new_with_label(_("Jump to beginning of page when using keyboard"));
         gtk_table_attach(GTK_TABLE(table), dlg->auto_jump,
-                         0, 1, 6, 7,
+                         0, 1, 7, 8,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
@@ -598,7 +611,6 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->auto_jump);
 
-
         label = gtk_label_new(_("Layout"));
         gtk_widget_show(label);
         gtk_widget_show(table);
