@@ -125,19 +125,6 @@ sync_toolbar_style(GgvWindow *win)
                                      ggv_toolbar_labels?"both":"icon", NULL);
 }
 
-static void
-set_file_items_sensitivity(GgvWindow *win, gboolean sens)
-{
-        gchar *prop_val = sens?"1":"0";
-
-	bonobo_ui_component_set_prop(win->uic, "/commands/FileSaveMarked",
-                                     "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(win->uic, "/commands/FilePrintMarked",
-                                     "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(win->uic, "/commands/FilePrintAll",
-                                     "sensitive", prop_val, NULL);
-}
-
 static void
 control_property_changed_handler(BonoboListener    *listener,
                                  char              *event_name, 
@@ -166,7 +153,6 @@ control_property_changed_handler(BonoboListener    *listener,
                         return;
 
                 win->current_page = BONOBO_ARG_GET_INT(any);
-                set_file_items_sensitivity(win, win->current_page >= 0);
                 if(win->current_page < 0) {
                         GtkWidget *dlg;
                         dlg = gtk_message_dialog_new(GTK_WINDOW(win),
@@ -249,10 +235,26 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
         if(!GTK_WIDGET_VISIBLE(win->file_sel)) {
                 gtk_widget_set_usize(GTK_WIDGET(win->file_sel),
                                      file_sel_width, file_sel_height);
+                if(win->filename) {
+                        gchar *path = g_path_get_dirname(win->filename);
+			gchar *path2 = g_strconcat(path, "/", NULL);
+			g_free(path);
+                        gtk_file_selection_set_filename(GTK_FILE_SELECTION(win->file_sel), path2);
+                        g_free(path2);
+                }
                 gtk_widget_show(win->file_sel);
+		ggv_raise_and_focus_widget(win->file_sel);
         }
 }
 
+static void
+verb_FileReload(BonoboUIComponent *uic, gpointer data, const char *cname)
+{
+        GgvWindow *win = GGV_WINDOW(data);
+
+        ggv_window_load(win, win->filename);
+}
+
 static void
 verb_FileClose(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
@@ -381,6 +383,13 @@ verb_HelpAbout(BonoboUIComponent *uic, gpointer data, const char *cname)
 	ggv_raise_and_focus_widget (about);
 }
 
+static void
+verb_HelpContents(BonoboUIComponent *uic, gpointer data, const char *cname)
+{
+	GError *error = NULL;
+	gnome_help_display ("ggv",NULL,&error);
+}
+
 static void
 verb_DnDNewWindow(BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
@@ -438,8 +447,10 @@ static BonoboUIVerb ggv_app_verbs[] = {
         BONOBO_UI_VERB("FileNew", verb_FileNew),
         BONOBO_UI_VERB("FileClose", verb_FileClose),
         BONOBO_UI_VERB("FileOpen", verb_FileOpen),
+        BONOBO_UI_VERB("FileReload", verb_FileReload),
         BONOBO_UI_VERB("FileExit", verb_FileExit),
         BONOBO_UI_VERB("HelpAbout", verb_HelpAbout),
+        BONOBO_UI_VERB("Help", verb_HelpContents),
         BONOBO_UI_VERB("DnDNewWindow", verb_DnDNewWindow),
         BONOBO_UI_VERB("DnDThisWindow", verb_DnDThisWindow),
         BONOBO_UI_VERB("DnDCancel", verb_DnDCancel),
@@ -477,8 +488,13 @@ ggv_window_destroy(GtkObject *object)
                 win->ctlframe = NULL;
         }
 
+        if(win->filename) {
+                g_free(win->filename);
+                win->filename = NULL;
+        }
+
         ggv_get_window_size(GTK_WIDGET(object),
-                        &ggv_default_width, &ggv_default_height);
+                            &ggv_default_width, &ggv_default_height);
 
         if(GTK_OBJECT_CLASS(parent_class)->destroy)
                 GTK_OBJECT_CLASS(parent_class)->destroy(object);
@@ -572,7 +588,7 @@ ggv_window_new(void)
         }
         CORBA_exception_free(&ev);
 
-	win = GGV_WINDOW(g_object_new(GGV_TYPE_WINDOW, NULL));
+	win = GGV_WINDOW(g_object_new(GGV_TYPE_WINDOW, "win_name", "ggv", "title", _("Gnome Ghostview"), NULL));
         win->control = control;
 
         win->current_page = -2;
@@ -600,9 +616,6 @@ ggv_window_new(void)
 	gtk_box_pack_end(GTK_BOX(win->vbox), GTK_WIDGET(win->statusbar),
                          FALSE, FALSE, 0);
 
-	ui_container = bonobo_ui_container_new();
-	bonobo_window_construct(BONOBO_WINDOW(win), ui_container,
-                                "ggv", _("Gnome Ghostview"));
         bonobo_window_set_contents(BONOBO_WINDOW(win), win->vbox);
 
 	gtk_drag_dest_set (GTK_WIDGET (win),
@@ -612,6 +625,8 @@ ggv_window_new(void)
 			   GDK_ACTION_COPY | GDK_ACTION_ASK);
 
 	/* add menu and toolbar */
+	ui_container = bonobo_window_get_ui_container(BONOBO_WINDOW(win));
+	BONOBO_OBJREF(ui_container);
 	uic = bonobo_ui_component_new("ggv");
         win->uic = uic;
 	bonobo_ui_component_set_container(uic, BONOBO_OBJREF(ui_container),
@@ -685,8 +700,6 @@ ggv_window_new(void)
                 sync_settings_popup_items(win);
         }
 
-        set_file_items_sensitivity(win, FALSE);
-
 	/* set default geometry */
         gtk_widget_set_usize(GTK_WIDGET(win),
                              ggv_default_width, ggv_default_height);
@@ -740,7 +753,9 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
         Bonobo_PersistFile_load(pf, full_path, &ev);
         bonobo_object_release_unref(pf, NULL);
 
-        g_free(full_path);
+        if(win->filename)
+                g_free(win->filename);
+        win->filename = full_path;
 
         if(BONOBO_EX(&ev)) {
                 CORBA_exception_free(&ev);
